// ==============================================================
//                 ORBITER MODULE: tgo_heatshield
//                  
//
// tgo_heatshield.cpp
// Control module for tgo_heatshield vessel class
//
// 
// ==============================================================

#define STRICT
#define ORBITER_MODULE

#include "orbitersdk.h"
//#include "OrbiterSoundSDK40.h"
//#include <cstdio>
//#include <cmath>
//#include <string>
#include <stdio.h>
#include <math.h>

// ==============================================================
// Some vessel parameters
// ==============================================================



const double MASS = 80;

static TOUCHDOWNVTX tdvtx_geardown[3] = {
	{_V( 0, 2, 0.2), 1e4, 1e4, 0.5, 0.5},
	{_V(-1.732,-1, 0.2), 1e4, 1e4, 0.5, 0.5},
	{_V( 1.732,-1, 0.2), 1e4, 1e4, 0.5, 0.5}
};


class tgo_heatshield: public VESSEL3 {
public:
	
	tgo_heatshield (OBJHANDLE hVessel, int flightmodel);
	~tgo_heatshield ();

	void clbkSetClassCaps (FILEHANDLE cfg);
	void clbkPreStep(double SimT, double SimDT, double MJD);
	void clbkPostStep (double simt, double simdt, double mjd);
	void clbkPostCreation();
	//int MyID;
	

private:
	
};

tgo_heatshield::tgo_heatshield (OBJHANDLE hVessel, int flightmodel)
: VESSEL3 (hVessel, flightmodel)
{
}

tgo_heatshield::~tgo_heatshield ()
{
	
}



// ==============================================================
// tgo_heatshield class interface
// ==============================================================

// ==============================================================
// Overloaded callback functions
// ==============================================================

// --------------------------------------------------------------
// Set the capabilities of the vessel class
// --------------------------------------------------------------
void tgo_heatshield::clbkSetClassCaps (FILEHANDLE cfg)
{
	
	// physical specs
	SetEmptyMass(MASS);
	SetCW (2, 2, 1, 1);
	SetRotDrag (_V(2,2,2));
	SetPMI (_V(1,1,2));
	SetCrossSections (_V(1,1,3));
	SetSize (2);
	SetMeshVisibilityMode ((AddMesh ("TGO/tgo_htshld")), MESHVIS_EXTERNAL);
	SetCameraOffset (_V(0,0,0));
	//SetTouchdownPoints (_V(0, 1, 0.2), _V(-0.866, -0.5, 0.2), _V(0.866, -0.5, 0.2));
	SetTouchdownPoints (tdvtx_geardown, 3);
	//SetSurfaceFrictionCoeff (0.7,0.7);

}

// ==============================================================
// API callback interface
// ==============================================================

// --------------------------------------------------------------
// Vessel initialisation
// --------------------------------------------------------------
DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel)
{
	return new tgo_heatshield (hvessel, flightmodel);
}




// --------------------------------------------------------------
// Vessel cleanup
// --------------------------------------------------------------
DLLCLBK void ovcExit (VESSEL *vessel)
{
	if (vessel) delete (tgo_heatshield*)vessel;
}
// ==============================================================
// Overloaded clbkPostCreation callback functions
// ==============================================================

void tgo_heatshield::clbkPostCreation ()
{
	//MyID=ConnectToOrbiterSoundDLL(GetHandle());
	////ReplaceStockSound(MyID,"Sound\\Vessel\\ambient5.wav",	REPLACE_WHEELBRAKE);
	//ReplaceStockSound(MyID,"Sound\\Vessel\\ambient5.wav",	REPLACE_LAND_TOUCHDOWN);
	////ReplaceStockSound(MyID,"NULL",	REPLACE_LAND_TOUCHDOWN);
	////SoundOptionOnOff(MyID,PLAYMAINTHRUST,FALSE);
	////SoundOptionOnOff(MyID,PLAYRETROTHRUST,FALSE);
	////SoundOptionOnOff(MyID,PLAYHOVERTHRUST,FALSE);
	//SoundOptionOnOff(MyID,PLAYRADIOATC,FALSE);
	//SoundOptionOnOff(MyID,PLAYGPWS,FALSE);
	//SoundOptionOnOff(MyID,PLAYCOUNTDOWNWHENTAKEOFF,FALSE);
	////SoundOptionOnOff(MyID,PLAYLANDINGANDGROUNDSOUND,FALSE);
	//SoundOptionOnOff(MyID,PLAYCABINAIRCONDITIONING,FALSE);
	//SoundOptionOnOff(MyID,PLAYCABINRANDOMAMBIANCE,FALSE);
	//SoundOptionOnOff(MyID,DISPLAYTIMER,FALSE);
	//SoundOptionOnOff(MyID,PLAYDOCKLANDCLEARANCE,FALSE);
	//SoundOptionOnOff(MyID,PLAYRADARBIP,FALSE);
	
}


void tgo_heatshield::clbkPreStep(double SimT, double SimDT, double MJD) 
{
	//DWORD lsw = GetFlightStatus();
	//if (lsw > 0)
	//{
	//	if (GetAltitude(ALTMODE_GROUND) < 10)
	//	{
	//		double lng, lat, rdi = 0;
	//		oapiGetEquPos(GetHandle(), &lng, &lat, &rdi);
	//		double hdg = 0;
	//		oapiGetHeading(GetHandle(), &hdg);
	//		VESSELSTATUS2 vs;
	//		memset (&vs, 0, sizeof(vs));
	//		vs.version = 2;
	//		GetStatusEx(&vs);
	//		vs.status = 1;
	//		vs.surf_hdg = hdg;
	//		vs.surf_lat = lat;
	//		vs.surf_lng = lng;
	//		DefSetStateEx (&vs);
	//	}
	//}
}

void tgo_heatshield::clbkPostStep (double simt, double simdt, double mjd)
{


}


